@@ -5,7 +5,7 @@ oer - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2002 EQU <equ@equnet.org>
+Copyright (C) 2000-2003 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -27,7 +27,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 extern char *safeban(struct channel *, char *, char *);
 extern char *getfirsthostless(struct channel *, char *);
 extern char *getkickreason(char *);
-extern char *deltopic(struct channel *, int, char *);
 extern char getmodepol(char *, char);
 extern int partcount(struct channel *, char *, char *);
 extern int loadall(void);
@@ -126,6 +125,8 @@ extern int noexpiredlogons(struct channel *);
 extern int delchannelban(struct channel *, char *);
 extern int ischanopless(struct channel *);
 extern int joininprogress(void);
+extern int getmmodecount(struct channel *);
+extern int gettimedcount(void);
 extern unsigned int getrandom(unsigned int);
 extern long getfilesize(char *);
 extern struct authed *addnewauthed(struct channel *, time_t, struct botuser *, char *);
@@ -177,6 +178,8 @@ extern void initchannel(struct channel *);
 extern void initall(void);
 extern void initnicks(struct channel *);
 extern void initmmodes(struct channel *);
+extern void initmmodesfornick(struct channel *, char *);
+extern void changemmodesfornick(struct channel *, char *, char *);
 extern void initparts(struct channel *);
 extern void initjoins(struct channel *);
 extern void initnickbks(struct channel *);
@@ -239,3 +242,4 @@ extern void mmode_del(struct channel *, struct mmode *);
 extern void validateflags(char *, char *, int);
 extern void resetfloodcounters(struct channel *, char *);
 extern void resetcommand(struct channel *, char *, int, char *, char *, char *);
+extern void deltopic(struct channel *, char *, int, char *, char *, char *);
