@@ -5,7 +5,7 @@ oer - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2002 EQU <equ@equnet.org>
+Copyright (C) 2000-2003 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -32,6 +32,8 @@ int iscomment(char *);
 int isserver(char *);
 int isvaliduserhost(char *);
 int isvalidhost(char *);
+int isvalidipv4host(char *);
+int isvalidipv6host(char *);
 int isansi(char *);
 int isaction(char *);
 int isctcp(char *);
@@ -41,6 +43,8 @@ int issamenickandhost(char *, char *, char *, char *);
 int issimilarstring(char *, char *);
 int isnumbw(int, int, int);
 int completeban(char *, char *, int);
+int countchars(char *, char);
+int countnchars(char *, char);
 unsigned int longestword(char *);
 unsigned int isgoodquote(char *);
 char *mybasename(char *);
@@ -606,27 +610,45 @@ int isnumbw(int number, int low, int high)
 
 int isvalidhost(char *line)
 {
-        int c;
-        int c2;
-        char *ptr;
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_INFO, "isvalidhost->%s\n", line);
+#endif
+        /* check for IPv4 or IPv6 hostname */
+        if(!isvalidipv4host(line) && !isvalidipv6host(line)) {
+                return 0;
+        }
+        return 1;
+}
 
+int isvalidipv4host(char *line)
+{
+        char *ptr;
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_INFO, "isvalidipv4host->%s\n", line);
+#endif
         /* we require at least X.Y */
-        if(strlen(line) < 3) {
+        if(strlen(line) < 3 || (ptr = index(line, '.')) == NULL) {
                 return 0;
         }
-        /* we require a domain and a TLD */
-        if((ptr = index(line, '.')) == NULL) {
+        /* we want both X and Y to be printable */
+        if(!isgraph(*(ptr - 1)) || !isgraph(*(ptr + 1))) {
                 return 0;
         }
-        /* the domain and TLD separator can't be the
-           first nor the last character */
+        /* the domain nor the TLD separator can't be the
+           first nor the last character of the hostname */
         if(ptr == line || ptr == (line + (strlen(line) - 1))) {
                 return 0;
         }
-        c = *(ptr - 1);
-        c2 = *(ptr + 1);
-        /* we want both X and Y to be printable */
-        if(!isgraph(c) || !isgraph(c2)) {
+        return 1;
+}
+
+int isvalidipv6host(char *line)
+{
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_INFO, "isvalidipv6host->%s\n", line);
+#endif
+        /* we require at least ::X */
+        if(countchars(line, ':') < 2 || countnchars(line, ':') < 1) {
                 return 0;
         }
         return 1;
@@ -677,3 +699,31 @@ char *mybasename(char *ptr)
 		return NULL;
 	}
 }
+
+int countchars(char *line, char ch)
+{
+        int length;
+        int counter;
+        int matchcount;
+
+        for(length = strlen(line), counter = 0, matchcount = 0; counter < length; counter++) {
+                if(line[counter] == ch) {
+                        matchcount++;
+                }
+        }
+        return matchcount;
+}
+
+int countnchars(char *line, char ch)
+{
+        int length;
+        int counter;
+        int matchcount;
+
+        for(length = strlen(line), counter = 0, matchcount = 0; counter < length; counter++) {
+                if(line[counter] != ch) {
+                        matchcount++;
+                }
+        }
+        return matchcount;
+}
