@@ -5,7 +5,7 @@ oer - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2002 EQU <equ@equnet.org>
+Copyright (C) 2000-2003 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -34,6 +34,7 @@ int do_console;
 int do_debug;
 int do_output;
 int do_tempoutput;
+int do_altlogging;
 
 char salt_chars[] = { "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz" };
 char timed_str[WRITE_BUFFER_LENGTH + 1];
@@ -57,6 +58,8 @@ int main(int argc, char *argv[])
 	char *locptr;
 #endif
 	char stringbuffer[WRITE_BUFFER_LENGTH + 1];
+	char altloggingdir[STRINGLEN + 1];
+	char basedir[STRINGLEN + 1];
 	int retval;
 	int c;
 	int do_help;
@@ -65,6 +68,7 @@ int main(int argc, char *argv[])
 	FILE *pidfile;
 	pid_t newpid;
 	struct timeval tv;
+	struct stat st;
 #ifdef NEW_SIGNALS
         struct sigaction act;
 	struct sigaction old;
@@ -74,9 +78,14 @@ int main(int argc, char *argv[])
 	do_help = 0;
 	do_output = 0;
 	do_signals = 1;
+	do_altlogging = 0;
 	do_version = 0;
 	do_tempoutput = 1;
-	while((c = getopt(argc, argv, "cd:hosv")) > 0) {
+	if(getcwd(&basedir[0], STRINGLEN) == NULL) {
+		oer_debug(OER_DEBUG_FATAL, "couldn't get current directory\n");
+		exit(EXIT_FAILURE);
+	}
+	while((c = getopt(argc, argv, "cd:f:hl:osv")) > 0) {
 		switch(c) {
 		case 'c':
 			do_console = 1;
@@ -84,9 +93,16 @@ int main(int argc, char *argv[])
 		case 'd':
 			do_debug = atoi(optarg);
 			break;
+		case 'f':
+			strncpy(basedir, optarg, STRINGLEN);
+			break;
 		case 'h':
 			do_help = 1;
 			break;
+		case 'l':
+			strncpy(altloggingdir, optarg, STRINGLEN);
+			do_altlogging = 1;
+			break;
 		case 'o':
 			do_output = 1;
 			break;
@@ -101,7 +117,7 @@ int main(int argc, char *argv[])
 		}
 	}
 	if(do_help) {
-		oer_debug(OER_DEBUG_INFO, "%s: oer [-c] [-d <level>] [-h] [-o] [-s] [-v]\n", argv[0]);
+		oer_debug(OER_DEBUG_INFO, "%s: oer [-c] [-d <level>] [-f <basedir>] [-h] [-l <logging dir>] [-o] [-s] [-v]\n", argv[0]);
 		exit(EXIT_SUCCESS);
 	}
 	oer_debug(OER_DEBUG_INFO, "%s, %s\n\n", OER_VERSION, OER_COPYRIGHT1);
@@ -109,13 +125,13 @@ int main(int argc, char *argv[])
 	if(do_version) {
 		exit(EXIT_SUCCESS);
 	}
-	/* check if there is already a oer running started from this
-	   directory */
-	if((pidfile = fopen("oer.pid", "r")) != NULL) {
+	/* check if there is already a oer running */
+	snprintf(stringbuffer, STRINGLEN, "%s/oer.pid", basedir);
+	if((pidfile = fopen(stringbuffer, "r")) != NULL) {
 		if(fgets(stringbuffer, WRITE_BUFFER_LENGTH, pidfile)) {
 			/* exists, check if process is running */
 			if(!kill(atoi(stringbuffer), SIGHUP)) {
-				oer_debug(OER_DEBUG_FATAL, "main->oer seems to be running, if this is not the case remove oer.pid from the current directory\n");
+				oer_debug(OER_DEBUG_FATAL, "main->oer seems to be running, if this is not the case remove oer.pid from %s\n", basedir);
 				fclose(pidfile);
 				exit(EXIT_FAILURE);
 			}
@@ -147,7 +163,8 @@ int main(int argc, char *argv[])
 		do_console = 0;
 	}
 	/* create new pidfile */
-	if((pidfile = fopen("oer.pid", "w")) == NULL) {
+	snprintf(stringbuffer, STRINGLEN, "%s/oer.pid", basedir);
+	if((pidfile = fopen(stringbuffer, "w")) == NULL) {
 		oer_debug(OER_DEBUG_FATAL, "main->couldn't open oer.pid: %s\n", strerror(errno));
 		exit(EXIT_FAILURE);
 	}	
@@ -208,9 +225,24 @@ int main(int argc, char *argv[])
 		oer_debug(OER_DEBUG_INFO, "main->failed to allocate memory for irc state\n");
 		exit(EXIT_FAILURE);
 	}
-	strncpy(mystate->progname, argv[0], STRINGLEN);
+	strncpy(mystate->basedir, basedir, STRINGLEN);
+	oer_debug(OER_DEBUG_INFO, "main->basedir is %s\n", mystate->basedir);
+	strncpy(mystate->progname, mybasename(argv[0]), STRINGLEN);
+	oer_debug(OER_DEBUG_INFO, "main->progname is %s\n", mystate->progname);
+	if(do_altlogging) {
+		if(!stat(altloggingdir, &st)) {
+			if(S_IFDIR & st.st_mode) {
+				strncpy(mystate->altloggingdir, altloggingdir, STRINGLEN);
+				oer_debug(OER_DEBUG_INFO, "main->using alternative logging directory %s\n", mystate->altloggingdir);
+			}
+		}
+	}
 	if(do_output) {
-		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "oer-%d.output", getpid());
+		if(strlen(mystate->altloggingdir)) {
+			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "%s/oer-%d.output", mystate->altloggingdir, getpid());
+		} else {
+			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "oer-%d.output", getpid());
+		}
 		if((mystate->logto = fopen(stringbuffer, "a+")) == NULL) {
 			oer_debug(OER_DEBUG_INFO, "main->couldn't open output file %s: %s\n", stringbuffer, strerror(errno));
 			exit(EXIT_FAILURE);
@@ -219,9 +251,7 @@ int main(int argc, char *argv[])
 	}
 	/* from now on we write to console and/or file */
 	do_tempoutput = 0;
-#ifdef DEBUG
 	oer_debug(OER_DEBUG_INFO, "main->%s (%s %s) starting up\n", OER_VERSION, __DATE__, __TIME__);
-#endif
 	if(!loadall()) {
 		oer_debug(OER_DEBUG_INFO, "main->loadall() failed\n");
 		exit(EXIT_FAILURE);
@@ -230,7 +260,11 @@ int main(int argc, char *argv[])
                 oer_debug(OER_DEBUG_INFO, "console mode is on (debug messages will be shown on screen)\n");
         }
 	if(index(mystate->flags, (int)'l') != NULL) {
-		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "oer-%d.raw", getpid());
+		if(strlen(mystate->altloggingdir)) {
+			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "%s/oer-%d.raw", mystate->altloggingdir, getpid());
+		} else {
+			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "oer-%d.raw", getpid());
+		}
 		if((mystate->logfp = fopen(stringbuffer, "a+")) == NULL) {
 			oer_debug(OER_DEBUG_INFO, "main->couldn't open raw file %s: %s\n", stringbuffer, strerror(errno));
 			exit(EXIT_FAILURE);
@@ -253,10 +287,8 @@ int main(int argc, char *argv[])
 		retval = select(mystate->sockfd + 1, &rsock, NULL, NULL, &tv);
 		mystate->now = time(NULL);
 		if(retval < 0) {
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_INFO, "main->select() failed: %s\n", strerror(errno));
-#endif
 			if(errno != EINTR) {
+				oer_debug(OER_DEBUG_ERROR, "main->select() failed: %s\n", strerror(errno));
 				mystate->reconnect = OER_RECONNECT_ERROR;
 				reconnect();
 			}
