@@ -5,7 +5,7 @@ oer - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000-2002 EQU <equ@equnet.org>
+Copyright (C) 2000-2003 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -855,10 +855,15 @@ void parseirc(char *serveroutput)
 			return;
 		}
 		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
-		strncpy(channel, params, CHANLEN);
-		if((this = getchptr(channel)) == NULL) {
-			return;
-		}
+		/* ircu PART behaviour has changed, why? */
+                if(params[0] == ':') {
+                        strncpy(channel, params + 1, CHANLEN);
+                } else {
+                        strncpy(channel, params, CHANLEN);
+                }
+                if((this = getchptr(channel)) == NULL) {
+                        return;
+                }
 		if(isme(temp_nick)) {
 			this->rejoin_at = mystate->now + OER_DELAY_BETWEEN_REJOINS;
 			if(this->nickcount == 1 && !this->i_am_op) {
@@ -1822,7 +1827,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		if(!strlen(restptr)) {
 			/* the messager wants to be opped */
-			if(isopnow(this, nick)) {
+			if(!isonchan(this, nick) || isopnow(this, nick)) {
 				return;
 			}
 			if(haschanflags(this, "u") && !isallowedop(this, nick)) {
@@ -1839,7 +1844,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(isopnow(this, p1)) {
+			if(!isonchan(this, p1) || isopnow(this, p1)) {
 				continue;
 			}
 			if(haschanflags(this, "u") && !isallowedop(this, p1)) {
@@ -1863,7 +1868,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		if(!strlen(restptr)) {
 			/* the messager wants to be de-opped */
-			if(!isopnow(this, nick)) {
+			if(!isonchan(this, nick) || !isopnow(this, nick)) {
 				return;
 			}
 			if(haschanflags(this, "D") && isallowedop(this, nick)) {
@@ -1880,7 +1885,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(!isopnow(this, p1)) {
+			if(!isonchan(this, p1) || !isopnow(this, p1)) {
 				continue;
 			}
 			if(haschanflags(this, "D") && isallowedop(this, p1)) {
@@ -1904,7 +1909,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		if(!strlen(restptr)) {
 			/* the messager wants to be voiced */
-			if(!isvoicenow(this, nick)) {
+			if(isonchan(this, nick) && !isvoicenow(this, nick)) {
 				mmode_new(this, mystate->now, "+v", nick);
 			}
 			return;
@@ -1917,7 +1922,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(!isvoicenow(this, p1)) {
+			if(isonchan(this, p1) && !isvoicenow(this, p1)) {
 				mmode_new(this, mystate->now, "+v", p1);
 			}
 		}
@@ -1937,7 +1942,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		if(!strlen(restptr)) {
 			/* the messager wants to be devoiced */
-			if(isvoicenow(this, nick)) {
+			if(isonchan(this, nick) && isvoicenow(this, nick)) {
 				mmode_new(this, mystate->now, "-v", nick);
 			}
 			return;
@@ -1950,7 +1955,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(isvoicenow(this, p1)) {
+			if(isonchan(this, p1) && isvoicenow(this, p1)) {
 				mmode_new(this, mystate->now, "-v", p1);
 			}
 		}
